<img src="./flarefly_logo.png" width="200" height="200" /> <sub><sup>Logo by Andrea Sofia Triolo</sup></sub>

[![](https://img.shields.io/github/license/flarefly/flarefly)](https://github.com/hipe4ml/hipe4ml-converter/blob/main/LICENSE)
[![](https://img.shields.io/pypi/pyversions/flarefly.svg?longCache=True)](https://pypi.org/project/flarefly/)
[![](https://img.shields.io/pypi/v/flarefly.svg?maxAge=3600)](https://pypi.org/project/flarefly/)
![](https://github.com/hipe4ml/flarefly/actions/workflows/pythonpackage.yml/badge.svg?branch=main)
![](https://github.com/hipe4ml/flarefly/actions/workflows/pythonpublish.yml/badge.svg)

# Introduction
FLexible And REliable Fitting LibrarY is a library to perform fits to distributions for particle physics analysis

# Documentation

[https://flarefly.github.io/flarefly/index.html](https://flarefly.github.io/flarefly/index.html)
